==> haskell-crypton-x509-store-1.6.10-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-x509-store.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-x509-store
version:              1.6.10
visibility:           public
id:                   crypton-x509-store-1.6.10-4MfVQqgftraCc9PME04XAb
key:                  crypton-x509-store-1.6.10-4MfVQqgftraCc9PME04XAb
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-certificate
synopsis:             X.509 collection accessing and storing methods
description:
    X.509 collection accessing and storing methods for certificate, crl, exception list

category:             Data
abi:                  fd3b06d31d87b9c1b3c57cd24c4c1dfb
exposed:              True
exposed-modules:
    Data.X509.CertificateStore Data.X509.File Data.X509.Memory

import-dirs:          /usr/lib/ghc-9.4.8/site-local/crypton-x509-store-1.6.10
library-dirs:         /usr/lib/ghc-9.4.8/site-local/crypton-x509-store-1.6.10
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/crypton-x509-store-1.6.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-x509-store
hs-libraries:         HScrypton-x509-store-1.6.10-4MfVQqgftraCc9PME04XAb
depends:
    asn1-encoding-0.9.6-9t58293E83TLF4D7MJhRyD
    asn1-types-0.3.4-CZ8FC2wBb7x72hegasMid7 base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    crypton-1.0.2-DulODFZwpTEB0ZStV9RIwJ
    crypton-x509-1.7.7-AXX8rIHACGuBEh2uZt02nK directory-1.3.7.1
    filepath-1.4.2.2 mtl-2.2.2 pem-0.2.4-5CPZ2cFwFKKEJkJiLtrz18

haddock-interfaces:
    /usr/share/doc/haskell-crypton-x509-store/html/crypton-x509-store.haddock

haddock-html:         /usr/share/doc/haskell-crypton-x509-store/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypton-x509-store-1.6.10-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-x509-store.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-x509-store
version:              1.6.10
visibility:           public
id:                   crypton-x509-store-1.6.10-BTADAkRlZ5RBBnBVFw7Mr0
key:                  crypton-x509-store-1.6.10-BTADAkRlZ5RBBnBVFw7Mr0
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-certificate
synopsis:             X.509 collection accessing and storing methods
description:
    X.509 collection accessing and storing methods for certificate, crl, exception list

category:             Data
abi:                  18cdf052e8d86875df2adeff46b98523
exposed:              True
exposed-modules:
    Data.X509.CertificateStore Data.X509.File Data.X509.Memory

import-dirs:          /usr/lib/ghc-9.4.8/site-local/crypton-x509-store-1.6.10
library-dirs:         /usr/lib/ghc-9.4.8/site-local/crypton-x509-store-1.6.10
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/crypton-x509-store-1.6.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-x509-store
hs-libraries:         HScrypton-x509-store-1.6.10-BTADAkRlZ5RBBnBVFw7Mr0
depends:
    asn1-encoding-0.9.6-6FOkoZ9nIzz88G5YnSdPFp
    asn1-types-0.3.4-DZJnlfHKxtrFWTCT1Kroh2 base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    crypton-1.0.2-3UyrY93yvpfJtnwDJwZ8bD
    crypton-x509-1.7.7-36d5uqE8Y2QAT4bFvZtaTM directory-1.3.7.1
    filepath-1.4.2.2 mtl-2.2.2 pem-0.2.4-3HJLbW7mkfO3NO47wY1r4P

haddock-interfaces:
    /usr/share/doc/haskell-crypton-x509-store/html/crypton-x509-store.haddock

haddock-html:         /usr/share/doc/haskell-crypton-x509-store/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
